import * as React from 'react';
import { View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import FontAwesome5 from 'react-native-vector-icons/FontAwesome5';
import Ionicons from 'react-native-vector-icons/Ionicons';
import { lstrings } from '../../common/locales/strings';
import { useHandler } from '../../hooks/useHandler';
import { useTheme } from '../services/ThemeContext';
import { EdgeText, Paragraph } from '../themed/EdgeText';
import { ModalTitle } from '../themed/ModalParts';
import { EdgeCard } from '../ui4/EdgeCard';
import { EdgeModal } from '../ui4/EdgeModal';
import { SectionView } from '../ui4/SectionView';
export const SecurityAlertsModal = (props) => {
    const { bridge, messages } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const otpResetNames = messages
        .filter(message => message.otpResetPending && message.username != null)
        .map(message => message.username);
    const voucherMessageNames = messages
        .filter(message => message.pendingVouchers.length > 0 && message.username != null)
        .map(message => message.username);
    const handleCancel = useHandler(() => bridge.resolve(undefined));
    const renderRow = (username, index) => {
        return (React.createElement(EdgeCard, { key: `${index}-${username}`, onPress: () => bridge.resolve(username) },
            React.createElement(View, { style: styles.cardContainer },
                React.createElement(EdgeText, null, username),
                React.createElement(FontAwesome5, { name: "chevron-right", size: theme.rem(1.25), color: theme.iconTappable, style: styles.chevron }))));
    };
    const renderLoginRequests = () => {
        if (voucherMessageNames.length === 0)
            return null;
        return (React.createElement(React.Fragment, null,
            React.createElement(Paragraph, null, lstrings.login_attempt_detected),
            voucherMessageNames.map((name, index) => renderRow(name !== null && name !== void 0 ? name : '', index))));
    };
    // TODO: Pending removal after server endpoint removal
    const renderOtpResetRequests = () => {
        if (otpResetNames.length === 0)
            return null;
        return (React.createElement(React.Fragment, null,
            React.createElement(Paragraph, null, lstrings.twofa_attempt_detected),
            otpResetNames.map((name, index) => renderRow(name !== null && name !== void 0 ? name : '', index))));
    };
    return (React.createElement(EdgeModal, { bridge: bridge, scroll: true, title: React.createElement(ModalTitle, { icon: React.createElement(Ionicons, { name: "warning", size: theme.rem(1.75), color: theme.warningText }) }, lstrings.review_login_request), onCancel: handleCancel },
        React.createElement(SectionView, { marginRem: [0.5, 0, 0.5] },
            renderLoginRequests(),
            renderOtpResetRequests())));
};
const getStyles = cacheStyles((theme) => ({
    cardContainer: {
        width: '100%',
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'space-between',
        margin: theme.rem(0.5)
    },
    chevron: {
        alignSelf: 'center',
        flexShrink: 0,
        marginHorizontal: theme.rem(1)
    }
}));
