var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { ActivityIndicator, ScrollView, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import Feather from 'react-native-vector-icons/Feather';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import Ionicons from 'react-native-vector-icons/Ionicons';
import { submitLogin } from '../../../actions/LoginCompleteActions';
import { lstrings } from '../../../common/locales/strings';
import { useImports } from '../../../hooks/useImports';
import { useDispatch } from '../../../types/ReduxTypes';
import { toLocalTime } from '../../../util/utils';
import { EdgeTouchableWithoutFeedback } from '../../common/EdgeTouchableWithoutFeedback';
import { Space } from '../../layout/Space';
import { Airship, showError } from '../../services/AirshipInstance';
import { useTheme } from '../../services/ThemeContext';
import { EdgeText, Paragraph, WarningText } from '../../themed/EdgeText';
import { IconHeaderRow } from '../../themed/IconHeaderRow';
import { LinkRow } from '../../themed/LinkRow';
import { ModalTitle } from '../../themed/ModalParts';
import { ThemedScene } from '../../themed/ThemedScene';
import { MessageText } from '../../themed/ThemedText';
import { AlertCard } from '../../ui4/AlertCard';
import { ButtonsView, StyledButtonContainer } from '../../ui4/ButtonsView';
import { EdgeButton } from '../../ui4/EdgeButton';
import { EdgeCard } from '../../ui4/EdgeCard';
import { EdgeModal } from '../../ui4/EdgeModal';
export class SecurityAlertsSceneComponent extends React.Component {
    constructor(props) {
        super(props);
        this.handleApproveReset = () => {
            const { account } = this.props;
            this.setState({ spinReset: true });
            account
                .disableOtp()
                .catch(error => showError(error))
                .then(() => this.setState({
                spinReset: false
            }));
        };
        this.handleDeny = (pendingVoucher) => () => __awaiter(this, void 0, void 0, function* () {
            const { account } = this.props;
            this.setState({ needsResecure: true });
            const { rejectVoucher = nopVoucher } = account;
            yield rejectVoucher(pendingVoucher.voucherId);
        });
        this.handleApproveVoucher = (pendingVoucher) => () => __awaiter(this, void 0, void 0, function* () {
            const { account } = this.props;
            const modalResult = yield Airship.show((bridge) => (React.createElement(ApproveVoucherModal, { bridge: bridge })));
            if (modalResult === 'allow') {
                this.setState(state => ({
                    spinVoucher: Object.assign(Object.assign({}, state.spinVoucher), { [pendingVoucher.voucherId]: true })
                }));
                const { approveVoucher = nopVoucher } = account;
                try {
                    yield approveVoucher(pendingVoucher.voucherId);
                    this.setState(state => ({
                        spinVoucher: Object.assign(Object.assign({}, state.spinVoucher), { [pendingVoucher.voucherId]: false })
                    }));
                }
                catch (error) {
                    showError(error);
                }
            }
            else if (modalResult === 'deny') {
                this.handleDeny(pendingVoucher);
            }
        });
        this.handleDenyAll = () => __awaiter(this, void 0, void 0, function* () {
            const { account } = this.props;
            const { otpResetDate, pendingVouchers } = this.state;
            this.setState({ needsResecure: true });
            const { rejectVoucher = nopVoucher } = account;
            const promises = pendingVouchers.map((voucher) => __awaiter(this, void 0, void 0, function* () { return yield rejectVoucher(voucher.voucherId); }));
            if (otpResetDate != null) {
                promises.push(account.cancelOtpReset());
            }
            yield Promise.all(promises);
        });
        this.handleSkip = () => {
            const { onDone } = this.props;
            onDone();
        };
        this.checkEmpty = () => {
            const { account, startResecure, onDone } = this.props;
            const { needsResecure, otpResetDate, pendingVouchers } = this.state;
            if (otpResetDate == null && pendingVouchers.length <= 0) {
                if (needsResecure)
                    startResecure(account);
                else
                    onDone();
            }
        };
        const { otpResetDate, pendingVouchers = [] } = props.account;
        this.state = {
            needsResecure: props.account.recoveryLogin,
            otpResetDate: otpResetDate != null ? new Date(otpResetDate) : undefined,
            pendingVouchers,
            spinReset: false,
            spinVoucher: {}
        };
    }
    componentDidMount() {
        const { account } = this.props;
        this.checkEmpty();
        this.cleanups = [
            account.watch('otpResetDate', otpResetDate => {
                const date = otpResetDate != null ? new Date(otpResetDate) : undefined;
                this.setState({ otpResetDate: date }, this.checkEmpty);
            }),
            account.watch('pendingVouchers', pendingVouchers => this.setState({ pendingVouchers }, this.checkEmpty))
        ];
    }
    componentWillUnmount() {
        if (this.cleanups != null)
            this.cleanups.forEach(f => f());
    }
    render() {
        const { otpResetDate, pendingVouchers } = this.state;
        const count = pendingVouchers.length + (otpResetDate != null ? 1 : 0);
        const renderButtons = () => {
            if (__DEV__) {
                return (React.createElement(ButtonsView, { layout: "column", primary: pendingVouchers.length <= 1
                        ? undefined
                        : {
                            label: lstrings.deny_all,
                            onPress: this.handleDenyAll
                        }, secondary: {
                        label: lstrings.skip_button,
                        onPress: this.handleSkip
                    } }));
            }
            else {
                return pendingVouchers.length <= 1 ? null : (React.createElement(ButtonsView, { layout: "column", primary: {
                        label: lstrings.deny_all,
                        onPress: this.handleDenyAll
                    } }));
            }
        };
        return (React.createElement(ThemedScene, null,
            React.createElement(ScrollView, { style: { flexGrow: 1, flexShrink: 0 } },
                React.createElement(IconHeaderRow, { renderIcon: theme => (React.createElement(FontAwesome, { name: "exclamation-triangle", size: theme.rem(2.5), color: theme.warningText })) },
                    React.createElement(MessageText, null, count > 1
                        ? lstrings.alert_scene_message_many_new
                        : lstrings.alert_scene_message)),
                React.createElement(AlertCard, { type: "warning", body: lstrings.alert_scene_warning_review }),
                this.renderVouchers(),
                this.renderReset()),
            renderButtons()));
    }
    // TODO: Pending removal after server endpoint removal
    renderReset() {
        const { theme } = this.props;
        const { otpResetDate, spinReset } = this.state;
        const styles = getStyles(theme);
        if (otpResetDate == null)
            return null;
        return (React.createElement(View, { style: styles.tile },
            React.createElement(MessageText, null, lstrings.alert_scene_reset_message),
            React.createElement(MessageText, null,
                lstrings.alert_scene_reset_date,
                otpResetDate.toLocaleString()),
            spinReset ? (React.createElement(ActivityIndicator, { color: theme.primaryButton[0], style: styles.cardSpinner })) : (React.createElement(LinkRow, { label: lstrings.alert_scene_approve, onPress: this.handleApproveReset }))));
    }
    renderVouchers() {
        const { theme } = this.props;
        const { pendingVouchers, spinVoucher } = this.state;
        const styles = getStyles(theme);
        return pendingVouchers.map(voucher => (React.createElement(EdgeCard, { key: voucher.voucherId },
            React.createElement(View, { style: styles.textBlock },
                voucher.deviceDescription != null ? (React.createElement(EdgeText, null, lstrings.alert_scene_device + voucher.deviceDescription)) : null,
                React.createElement(EdgeText, null, lstrings.alert_scene_ip + voucher.ipDescription),
                React.createElement(EdgeText, null, lstrings.alert_scene_date + toLocalTime(voucher.created))),
            React.createElement(View, { style: styles.textBlock },
                React.createElement(EdgeText, { numberOfLines: 2 },
                    React.createElement(WarningText, null, lstrings.alert_scene_reset_date + toLocalTime(voucher.activates)))),
            spinVoucher[voucher.voucherId] ? (React.createElement(ActivityIndicator, { color: theme.primaryButton[0], style: styles.cardSpinner })) : (
            // TODO: Codify this into a ButtonView variant if we need this
            // combination elsewhere. Hard-coded because it's assumed to be a
            // weird one-off situation.
            React.createElement(StyledButtonContainer, { layout: "row" },
                React.createElement(EdgeButton, { label: lstrings.allow, onPress: this.handleApproveVoucher(voucher), type: "secondary", layout: "row" }),
                React.createElement(Space, { aroundRem: 0.5 }),
                React.createElement(EdgeButton, { label: lstrings.deny, onPress: this.handleDeny(voucher), type: "destructive", layout: "row" }))))));
    }
}
const ApproveVoucherModal = (props) => {
    const { bridge } = props;
    const [isAgreed, setIsAgreed] = React.useState(false);
    const theme = useTheme();
    const styles = getStyles(theme);
    return (React.createElement(EdgeModal, { bridge: bridge, title: React.createElement(ModalTitle, { icon: React.createElement(Ionicons, { name: "warning", size: theme.rem(1.75), color: theme.warningText }) }, lstrings.access_confirmation_title), scroll: true, onCancel: () => bridge.resolve('dismiss') },
        React.createElement(Paragraph, null, lstrings.access_confirmation_body),
        React.createElement(EdgeTouchableWithoutFeedback, { onPress: () => setIsAgreed(!isAgreed) },
            React.createElement(View, { style: styles.checkBoxContainer },
                React.createElement(EdgeText, { style: styles.checkboxText }, lstrings.i_understand_agree),
                React.createElement(View, { style: [
                        styles.checkCircleContainer,
                        isAgreed ? styles.checkCircleContainerAgreed : undefined
                    ] }, isAgreed && (React.createElement(Feather, { name: "check", color: theme.iconTappable, size: theme.rem(0.75) }))))),
        React.createElement(StyledButtonContainer, { layout: "column", parentType: "modal" },
            React.createElement(EdgeButton, { disabled: !isAgreed, layout: "column", type: "secondary", onPress: () => bridge.resolve('allow') },
                React.createElement(View, { style: styles.allowButton },
                    React.createElement(Ionicons, { name: "warning", size: theme.rem(1.25), color: theme.warningText }),
                    React.createElement(EdgeText, { style: styles.allowButtonText }, lstrings.allow),
                    React.createElement(Ionicons, { name: "warning", size: theme.rem(1.25), color: theme.warningText }))),
            React.createElement(Space, { aroundRem: 0.5 }),
            React.createElement(EdgeButton, { label: lstrings.deny, layout: "column", type: "destructive", onPress: () => bridge.resolve('deny') }))));
};
function nopVoucher(voucherId) {
    return __awaiter(this, void 0, void 0, function* () {
        return yield Promise.resolve();
    });
}
const getStyles = cacheStyles((theme) => ({
    allowButton: {
        flexDirection: 'row'
    },
    allowButtonText: {
        marginHorizontal: theme.rem(0.5)
    },
    checkBoxContainer: {
        flexDirection: 'row',
        alignItems: 'center',
        marginHorizontal: theme.rem(0.5),
        marginTop: theme.rem(1),
        padding: theme.rem(1),
        borderWidth: theme.thinLineWidth,
        borderColor: theme.primaryText,
        borderRadius: theme.cardBorderRadius
    },
    checkCircleContainer: {
        justifyContent: 'center',
        alignItems: 'center',
        width: theme.rem(1.25),
        height: theme.rem(1.25),
        borderWidth: theme.thinLineWidth,
        borderColor: theme.icon,
        borderRadius: theme.rem(0.75)
    },
    checkCircleContainerAgreed: {
        borderColor: theme.iconTappable
    },
    checkboxText: {
        flex: 1,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(0.75)
    },
    buttonContainer: {
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'center',
        flexGrow: 1,
        flexShrink: 1,
        margin: theme.rem(0.5)
    },
    tile: {
        backgroundColor: theme.tileBackground,
        borderRadius: theme.rem(0.5),
        margin: theme.rem(0.5),
        padding: theme.rem(0.5)
    },
    cardSpinner: {
        alignSelf: 'flex-end',
        height: theme.rem(1.5),
        margin: theme.rem(0.5)
    },
    textBlock: {
        margin: theme.rem(0.5)
    }
}));
export function SecurityAlertsScene(props) {
    const { route } = props;
    const { account } = route.params;
    const { onComplete = () => { }, onLogin } = useImports();
    const dispatch = useDispatch();
    const theme = useTheme();
    const handleDone = () => {
        if (onLogin != null)
            dispatch(submitLogin(account));
        else
            onComplete();
    };
    const handleResecure = () => {
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'resecurePassword', params: { account } }
        });
    };
    return (React.createElement(SecurityAlertsSceneComponent, { account: account, route: route, startResecure: handleResecure, theme: theme, onDone: handleDone }));
}
