/**
 * IMPORTANT: Changes in this file MUST be synced with edge-react-gui!
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from 'react';
import { Platform, Text } from 'react-native';
import { fixSides, mapSides, sidesToMargin } from '../../util/sides';
import { cacheStyles, useTheme } from '../services/ThemeContext';
export const androidAdjustTextStyle = (theme) => {
    const styles = getStyles(theme);
    return Platform.OS === 'android' ? styles.androidAdjust : null;
};
// #region Spacing & Alignment =================================================
/** A properly spaced block of text with default font color and size. Children
 * that are wrapped in other `___Text` component types will override those defaults.
 *
 * A `Paragraph` *can* have `marginRem`, but *only* to avoid an extra `View` for
 * spacing out `Paragraph(s)` in relation to their parent, *NOT* to give special
 * spacing *between* `Paragraphs` */
export const Paragraph = (props) => {
    const { center = false, children, marginRem } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const margin = sidesToMargin(mapSides(fixSides(marginRem, 0.5), theme.rem));
    return (React.createElement(Text, { style: [
            styles.common,
            margin,
            center && styles.alignCenter,
            androidAdjustTextStyle(theme)
        ], numberOfLines: 0, adjustsFontSizeToFit: false }, children));
};
// TODO: Rename to LabelText
export const EdgeText = (props) => {
    var _a;
    const { children, style, disableFontScaling = false } = props, rest = __rest(props, ["children", "style", "disableFontScaling"]);
    const theme = useTheme();
    const styles = getStyles(theme);
    let { numberOfLines = 1 } = props;
    if (typeof children === 'string' && children.includes('\n')) {
        numberOfLines = numberOfLines + ((_a = children.match(/\n/g)) !== null && _a !== void 0 ? _a : []).length;
    }
    return (React.createElement(Text, Object.assign({ style: [styles.common, style, androidAdjustTextStyle(theme)], numberOfLines: numberOfLines, adjustsFontSizeToFit: !disableFontScaling, minimumFontScale: 0.65 }, rest), children));
};
/** Makes the contents of an `EdgeText` or `Paragraph` smaller (0.75rem).
 * Unless used within a `Paragraph` block, provides no outer spacing. */
export const SmallText = (props) => {
    const { children } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    return (React.createElement(Text, { style: [styles.sizeSmall, androidAdjustTextStyle(theme)] }, children));
};
/** Makes the contents of an `EdgeText` or `Paragraph` orange, for warnings.
 * Unless used within a `Paragraph` block, provides no outer spacing. */
export const WarningText = (props) => {
    const { children } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    return (React.createElement(Text, { style: [styles.colorWarning, androidAdjustTextStyle(theme)] }, children));
};
/** Makes the contents of an `EdgeText` or `Paragraph` large (1.5rem).
 * Unless used within a `Paragraph` block, provides no outer spacing. */
export const HeaderText = (props) => {
    const { children } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    return (React.createElement(Text, { style: [styles.sizeHeader, androidAdjustTextStyle(theme)] }, children));
};
// #endregion Typography
const getStyles = cacheStyles((theme) => ({
    androidAdjust: {
        top: -1
    },
    common: {
        color: theme.primaryText,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1),
        includeFontPadding: false
    },
    colorWarning: {
        color: theme.warningText
    },
    sizeSmall: {
        fontSize: theme.rem(0.75)
    },
    sizeHeader: {
        fontSize: theme.rem(1.5)
    },
    alignCenter: {
        textAlign: 'center'
    }
}));
